@@ -19,3 +19,6 @@ class CombatAbility(_DataSetIntFlags):
     DAMAGE_TARGET_ARMOR = 4
     ATTACK_GROUND = 8
     BULK_VOLLEY_RELEASE = 16
+    ENABLE_AURA_ABILITY = 32
+    INVERT_AURA_TO_BOOST_SELF = 64
+    ENABLE_STINGERS_ABILITY = 128
