@@ -26,12 +26,9 @@ def update_order_array(order_array: List[int], supposed_length: int) -> None:
     actual_length = len(order_array)
 
     if actual_length > supposed_length:
-        for i in range(supposed_length, actual_length):
-            order_array.remove(i)
+        order_array[:] = [x for x in order_array if x < supposed_length]
     elif supposed_length > actual_length:
-        for i in range(supposed_length):
-            if i not in order_array:
-                order_array.append(i)
+        order_array.extend(i for i in range(actual_length, supposed_length))
 
 
 # Written by: Ned Batchelder @ https://stackoverflow.com/a/312464/7230293
