@@ -89,11 +89,15 @@ class Effect(AoE2Object, TriggerComponent):
             RetrieverObjectLink("resource_2_quantity", support=Support(since=1.54)),
             RetrieverObjectLink("resource_3", support=Support(since=1.54)),
             RetrieverObjectLink("resource_3_quantity", support=Support(since=1.54)),
+            RetrieverObjectLink("decision_id", support=Support(since=1.54)),
+            RetrieverObjectLink("string_id_option1", support=Support(since=1.54)),
+            RetrieverObjectLink("string_id_option2", support=Support(since=1.54)),
+            RetrieverObjectLink("variable2", support=Support(since=1.54)),
             RetrieverObjectLink("message", commit_callback=_add_trail_if_string_attr_is_used_in_effect),
             RetrieverObjectLink("sound_name", commit_callback=_add_trail_if_string_attr_is_used_in_effect),
             RetrieverObjectLink("selected_object_ids"),
-            RetrieverObjectLink("unused_string_1", support=Support(since=1.54)),
-            RetrieverObjectLink("unused_string_2", support=Support(since=1.54)),
+            RetrieverObjectLink("message_option1", support=Support(since=1.54)),
+            RetrieverObjectLink("message_option2", support=Support(since=1.54)),
         ])
     ]
 
@@ -156,11 +160,15 @@ class Effect(AoE2Object, TriggerComponent):
             resource_2_quantity: int = None,
             resource_3: int = None,
             resource_3_quantity: int = None,
+            decision_id: int = None,
+            string_id_option1: int = None,
+            string_id_option2: int = None,
+            variable2: int = None,
             message: str = None,
             sound_name: str = None,
             selected_object_ids: List[int] = None,
-            unused_string_1: str = None,
-            unused_string_2: str = None,
+            message_option1: str = None,
+            message_option2: str = None,
             # Used for variable retrieval in armour/attack effects (source=variable only)
             _variable_ref: int = None,
             **kwargs
@@ -236,7 +244,7 @@ class Effect(AoE2Object, TriggerComponent):
         self.wood: int = wood
         self.stone: int = stone
         self.gold: int = gold
-        # self.item_id: int = item_id  # Unused (?)
+        self._item_id: int = item_id
         self.flash_object: int = flash_object
         self.force_research_technology: int = force_research_technology
         self.visibility_state: int = visibility_state
@@ -261,11 +269,15 @@ class Effect(AoE2Object, TriggerComponent):
         self.resource_2_quantity: int = resource_2_quantity
         self.resource_3: int = resource_3
         self.resource_3_quantity: int = resource_3_quantity
+        self.decision_id: int = decision_id
+        self.string_id_option1: int = string_id_option1
+        self.string_id_option2: int = string_id_option2
+        self.variable2: int = variable2
         self.message: str = message
         self.sound_name: str = sound_name
         self.selected_object_ids: List[int] = selected_object_ids
-        self.unused_string_1: str = unused_string_1
-        self.unused_string_2: str = unused_string_2
+        self.message_option1: str = message_option1
+        self.message_option2: str = message_option2
 
     @property
     def legacy_location_object_reference(self) -> int:
@@ -292,12 +304,11 @@ class Effect(AoE2Object, TriggerComponent):
             return self.technology
         if value_is_valid(self.tribute_list):
             return self.tribute_list
-        return -1
+        return self._item_id
 
     @item_id.setter
     def item_id(self, value):
-        raise ValueError("The `item_id` attribute is always equal to its corresponding attribute."
-                         "Please use that attribute (i.e. 'object_list_unit_id' or 'technology' or 'tribute_list').")
+        self._item_id = value
 
     @property
     def effect_type(self):
