@@ -1730,3 +1730,115 @@ class NewEffectSupport:
             source_player=source_player,
             player_color=player_color,
         )
+
+    def create_decision(
+            self,
+            decision_id: int | None = None,
+            string_id: int | None = None,
+            message: str | None = None,
+            string_id_option1: int | None = None,
+            message_option1: str | None = None,
+            string_id_option2: int | None = None,
+            message_option2: str | None = None,
+    ):
+        return self._trigger_ref._add_effect(
+            EffectId.CREATE_DECISION,
+            decision_id=decision_id,
+            string_id=string_id,
+            message=message,
+            string_id_option1=string_id_option1,
+            message_option1=message_option1,
+            string_id_option2=string_id_option2,
+            message_option2=message_option2,
+        )
+
+    def disable_unit_attackable(
+            self,
+            object_list_unit_id: int | None = None,
+            source_player: int | None = None,
+            area_x1: int | None = None,
+            area_y1: int | None = None,
+            area_x2: int | None = None,
+            area_y2: int | None = None,
+            selected_object_ids: int | List[int] | None = None,
+    ) -> Effect:
+        return self._trigger_ref._add_effect(
+            EffectId.DISABLE_UNIT_ATTACKABLE,
+            object_list_unit_id=object_list_unit_id,
+            source_player=source_player,
+            area_x1=area_x1,
+            area_y1=area_y1,
+            area_x2=area_x2,
+            area_y2=area_y2,
+            selected_object_ids=selected_object_ids,
+        )
+
+    def enable_unit_attackable(
+            self,
+            object_list_unit_id: int | None = None,
+            source_player: int | None = None,
+            area_x1: int | None = None,
+            area_y1: int | None = None,
+            area_x2: int | None = None,
+            area_y2: int | None = None,
+            selected_object_ids: int | List[int] | None = None,
+    ) -> Effect:
+        return self._trigger_ref._add_effect(
+            EffectId.ENABLE_UNIT_ATTACKABLE,
+            object_list_unit_id=object_list_unit_id,
+            source_player=source_player,
+            area_x1=area_x1,
+            area_y1=area_y1,
+            area_x2=area_x2,
+            area_y2=area_y2,
+            selected_object_ids=selected_object_ids,
+        )
+
+    def modify_variable_by_variable(
+            self,
+            variable: int | None = None,
+            operation: int | None = None,
+            variable2: int | None = None,
+    ):
+        """
+        How it works:
+
+        variable { operation }= variable2
+
+        Examples:
+
+            Operation.SET: variable = variable2
+            Operation.ADD: variable = variable + variable2
+            Operation.SUBTRACT: variable = variable - variable2
+            Operation.DIVIDE: variable = variable / variable2
+            Operation.MULTIPLY: variable = variable * variable2
+        """
+        return self._trigger_ref._add_effect(
+            EffectId.MODIFY_VARIABLE_BY_VARIABLE,
+            variable=variable,  # Destination!
+            operation=operation,
+            variable2=variable2,  # Modifier!
+        )
+
+    def count_units_into_variable(
+            self,
+            object_list_unit_id: int | None = None,
+            source_player: int | None = None,
+            area_x1: int | None = None,
+            area_y1: int | None = None,
+            area_x2: int | None = None,
+            area_y2: int | None = None,
+            object_group: int | None = None,
+            variable2: int | None = None,
+    ):
+        return self._trigger_ref._add_effect(
+            EffectId.COUNT_UNITS_INTO_VARIABLE,
+            object_list_unit_id=object_list_unit_id,
+            source_player=source_player,
+            area_x1=area_x1,
+            area_y1=area_y1,
+            area_x2=area_x2,
+            area_y2=area_y2,
+            object_group=object_group,
+            variable2=variable2,
+        )
